@@ -117,7 +117,11 @@ class Update:
                 if n is None:
                     n = ""
                 if o != n:
-                    output.append(f"   {key}: {json.dumps(o)} -> {json.dumps(n)}")
+                    if key not in [
+                        "text23",
+                        "text25",
+                    ]:
+                        output.append(f"   {key}: {json.dumps(o)} -> {json.dumps(n)}")
                     p[key] = n
             if output:
                 person["id"] = oid
